@@ -6,7 +6,7 @@ class Span(object):
     Basic unit for annotation. A span has `start`, `end`, `entity`, `value`.
     """
 
-    def __init__(self, start, end, entity, value=None, normal_value=None):
+    def __init__(self, start, end, entity, value=None, normal_value=None, role=None, group=None):
         if start < 0:
             raise OffsetSpanCheckError("start index should greater or equal than zero")
         if end <= start:
@@ -25,6 +25,8 @@ class Span(object):
         self.entity = entity
         # self.value = value
         self.normal_value = normal_value
+        self.role = role
+        self.group = group
 
         # document that this span binding to
         self.host = None
